@@ -1,22 +1,13 @@
 from pathlib import Path
-import importlib.resources
-from importlib.metadata import entry_points
 import json
 import os
+from importlib.abc import Traversable
 
 from nygen.conf import load_conf
 from nygen.lib.formatter import Formatter
 from nygen.lib.conda import create_conda, conda_exists
 from nygen.lib.exceptions import BadProjectNameException, DestinationExistsException, CondaEnvironmentExistsException, TemplateException
-
-
-def get_src_files(p: Path):
-    if p.is_file():
-        if not (p.name == "__pycache__" or p.name.endswith(".pyc")):
-            yield p
-    else:
-        for c in p.iterdir():
-            yield from get_src_files(c)
+from nygen.lib.template import get_template_files
 
 
 def is_dir_empty(p: Path) -> bool:
@@ -45,24 +36,13 @@ def precheck_conda(name):
 
 
 def get_path_maps(dst_root: Path, formatter: Formatter, template: str) -> list[tuple[Path, Path]]:
-    try:
-        template_entrypoint = next(iter(entry_points(group="nygen.templates", name=template)))
-    except StopIteration:
-        raise TemplateException(f"Invalid template: {template!r}")
-    template_module = template_entrypoint.load()
-    src_root: Path = importlib.resources.path(template_module, '.')
-    srcs = get_src_files(src_root)
-    path_maps = [(src, map_path(src, src_root, dst_root, formatter)) for src in srcs]
+    path_maps: list[tuple[Path, Path]] = []
+    for src, rel_src in get_template_files(template):
+        dst = dst_root / Path(formatter.format(str(rel_src)))
+        path_maps.append((src, dst))
     return path_maps
 
 
-def map_path(src: Path, src_root: Path, dst_root: Path, formatter: Formatter):
-    rel_src = src.relative_to(src_root)
-    rel_src = Path(formatter.format(str(rel_src)))
-    dst = dst_root / rel_src
-    return dst
-
-
 def gen_project(name, cmd_vars: dict[str, str], open_proj: bool, open_dir: bool, template: str):
     print(f"Generating project {name}")
     conf, conf_vars = load_conf()
